@@ -82,7 +82,7 @@ drag_received (GtkWidget * widget, GdkDragContext * context, gint x, gint y,
 			}
 			else
 			{
-				g_critical ("Could not load pixbuf: %s\n",
+				g_critical (_("Could not load pixbuf: %s\n"),
 					    error->message);
 				g_error_free (error);
 			}
@@ -120,7 +120,7 @@ func_gpp_remove (GtkWidget * widget, gpointer view)
 				    -1);
 
 /* Debug information
-		g_printf("File to remove: ->%s<-\n",file_name);
+		g_printf(_("File to remove: ->%s<-\n"),file_name);
 */
 		gpp_definition->number_of_files--;
 
@@ -186,7 +186,7 @@ func_gpp_add_ok (GtkWidget * widget, gpointer view)
 			}
 			else
 			{
-				g_critical ("Could not load pixbuf: %s\n",
+				g_critical (_("Could not load pixbuf: %s\n"),
 					    error->message);
 				g_error_free (error);
 
