@@ -51,10 +51,10 @@ gpp_print_pixbuf (GdkPixbuf * pixbuf)
 	width = gdk_pixbuf_get_width (pixbuf);
 
 	if (has_alpha)
-		gnome_print_rgbaimage (gpp_context, (char *) raw_image, width,
+		gnome_print_rgbaimage (gpp_context, (guchar *) raw_image, width,
 				       height, rowstride);
 	else
-		gnome_print_rgbimage (gpp_context, (char *) raw_image, width,
+		gnome_print_rgbimage (gpp_context, (guchar *) raw_image, width,
 				      height, rowstride);
 }
 
@@ -78,7 +78,7 @@ gpp_print_pictures (gchar * name)
 	pixbuf = gdk_pixbuf_new_from_file (file_name, &error);
 	if (!pixbuf)
 	{
-		g_print ("Could not load %s.\n", file_name);
+		g_print (_("Could not load %s.\n"), file_name);
 		return;
 	}
 
@@ -186,7 +186,7 @@ gpp_arrange_pictures (GtkWidget * progress_bar)
 	/* page is too small! */
 	if (i == -1 && j == -1)
         {
-                g_printf("paper size is to small!\n");
+                g_printf(_("paper size is to small!\n"));
                 return;
 	}
 
@@ -207,8 +207,8 @@ gpp_arrange_pictures (GtkWidget * progress_bar)
 	tree = GTK_TREE_MODEL (gpp_definition->file_names);
 	valid = gtk_tree_model_get_iter_first (tree, &iter);
 
-	gnome_print_config_get_length (gpp_config, GNOME_PRINT_KEY_PAGE_MARGIN_LEFT, &ml, NULL);
-	gnome_print_config_get_length (gpp_config, GNOME_PRINT_KEY_PAGE_MARGIN_BOTTOM, &mb, NULL);
+	gnome_print_config_get_length (gpp_config, (const guchar *) GNOME_PRINT_KEY_PAGE_MARGIN_LEFT, &ml, NULL);
+	gnome_print_config_get_length (gpp_config, (const guchar *) GNOME_PRINT_KEY_PAGE_MARGIN_BOTTOM, &mb, NULL);
 
 	space_x =
 		gpp_calculate_space_between_pics (gpp_definition->
