@@ -26,12 +26,19 @@ This file is part of Gnome Photo Printer.
 #include <libgnomeprint/gnome-print.h>
 #include <libgnomeprint/gnome-print-job.h>
 #include <libgnomeprintui/gnome-print-dialog.h>
+#include <libgnomeprintui/gnome-print-paper-selector.h>
 #include "gpp_print.h"
 #include "gpp_functions.h"
 #include "gpp_widget.h"
 #include "gpp_callbacks.h"
 #include "gpp.h"
 
+/* This header should probably be provided by libgnomeprintui-dev
+ * See http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=325497 for details */
+GtkWidget *        gnome_printer_selector_new (GnomePrintConfig *config);
+
+static GtkTargetEntry target_table[] = { {"text/uri-list", 0, 0} };
+
 /* Load the Glade File and build the Widget */
 GtkWidget *
 gpp_build_widget (gchar * file)
@@ -47,7 +54,7 @@ gpp_build_widget (gchar * file)
 	GtkTreeViewColumn *column;
 
 	/*
-	 * Load Glade file 
+	 * Load Glade file
 	 */
 	all = glade_xml_new (file, NULL, NULL);
 	window = glade_xml_get_widget (all, "window");
@@ -56,7 +63,7 @@ gpp_build_widget (gchar * file)
 		      TRUE, NULL);
 
 	/*
-	 * Create the TreeView 
+	 * Create the TreeView
 	 */
 	treeview = glade_xml_get_widget (all, "treeview");
 	gtk_tree_view_set_model (GTK_TREE_VIEW (treeview),
@@ -83,12 +90,12 @@ gpp_build_widget (gchar * file)
 				     GTK_SELECTION_SINGLE);
 
 	/*
-	 * Create Progressbar 
+	 * Create Progressbar
 	 */
 	progress = glade_xml_get_widget (all, "progress");
 
 	/*
-	 * bind Signals for Callbacks 
+	 * bind Signals for Callbacks
 	 */
 	glade_xml_signal_connect (all, "window_destroy",
 				  G_CALLBACK (func_gpp_quit));
@@ -113,7 +120,7 @@ gpp_build_widget (gchar * file)
 				       file_window);
 
 	/*
-	 * bind Signals for Layout Callbacks 
+	 * bind Signals for Layout Callbacks
 	 */
 	glade_xml_signal_connect_data (all, "layout_1_clicked",
 				       G_CALLBACK (func_gpp_layout),
@@ -148,13 +155,13 @@ gpp_build_widget (gchar * file)
 
     gpp_custom_units = (GtkComboBox *) glade_xml_get_widget (all, "custom_units");
 	gtk_combo_box_set_active(gpp_custom_units,0);
-	
+
 	gpp_pagesize = glade_xml_get_widget (all, "pagesize");
 	glade_xml_signal_connect_data (all, "on_ok_button_pagesize_clicked",
 				       G_CALLBACK (func_gpp_add_cancel),
 				       gpp_pagesize);
 	/*
-	 * bind Signals for Image Callbacks 
+	 * bind Signals for Image Callbacks
 	 */
 	glade_xml_signal_connect (all, "image_1_clicked",
 				  G_CALLBACK (func_gpp_image_1));
@@ -162,7 +169,7 @@ gpp_build_widget (gchar * file)
 				  G_CALLBACK (func_gpp_image_2));
 
 	/*
-	 * bind Signals for DND 
+	 * bind Signals for DND
 	 */
 	gtk_drag_dest_set (treeview, GTK_DEST_DEFAULT_ALL,
 			   target_table, 1, GDK_ACTION_COPY);
@@ -181,5 +188,5 @@ gpp_printer_selector_new ()
 GtkWidget *
 gpp_paper_selector_new ()
 {
-	return GTK_WIDGET (gnome_paper_selector_new (gpp_config));
+	return GTK_WIDGET (gnome_paper_selector_new_with_flags (gpp_config, GNOME_PAPER_SELECTOR_MARGINS | GNOME_PAPER_SELECTOR_FEED_ORIENTATION));
 }
